/* ------------------------------------------------------------------------------
    I N T K - T H E M E
--------------------------------------------------------------------------------- */

/* FONTS */

@font-face {
  font-family: 'BrandonText-Regular';
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Regular.otf') format('opentype');
}

@font-face {
  font-family: 'BrandonText-Bold';
  font-weight: bold;
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Bold.otf') format('opentype');
}

@font-face {
  font-family: 'BrandonText-Medium';
  font-weight: bold;
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Medium.otf') format('opentype');
}

@font-face {
  font-family: 'BrandonText-Black';
  font-weight: bold;
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Black.otf') format('opentype');
}

.no-space {
    margin-left: 0px !important;
}

#FooterPortlet .managePortletsLink {
    display: none;
}

.folder_contents_portlet_manager .managePortletsLink {
    display: none;
}


/* BODY */
body {
  background-color: #f4f4f4;
}

#portal-logo {
    width: 75px;
    height: 75px;
    margin-top: 50px;
    margin-left: 30px;
    margin-bottom: 0px;
}

/* LOGO */
@media (max-width: 767px) {
    #portal-logo {
        margin-top: 30px;
        margin-left: 20px;  
    }
}

@media (min-width: 992px) {
    #portal-logo {
        margin-top: 30px;
        margin-left: 20px;
    }
}

@media (max-width: 991px) and (min-width: 768px) {
    #portal-logo {
        margin-top: 25px;
        margin-left: 10px;
    }
}

@media (min-width: 1200px) {
    #portal-logo {
        margin-top: 50px;
        margin-left: 30px;
    }
}


#portal-logo img {
    width: 75px;
    height: 75px;
}

#content-core {
    background-color: #ffffff;
}

#parent-fieldname-title {
    font-size:24px;
    text-transform: uppercase;
    color: #242424;
    font-family: "BrandonText-Bold";
    line-height: 32px;
    margin: 0;
}

#content .documentDescription {
    font-size: 18px;
    color: #999999;
    font: 18px "BrandonText-Regular", Arial, FreeSans, sans-serif;
    line-height: 26px;
}

#parent-fieldname-description {
    padding-bottom: 65px;
}

#content a:link {
    text-decoration: none;
}

#parent-fieldname-title {
    padding-left: 20px;
    padding-right: 20px;
    padding-top: 42px;
}

@media (max-width: 979px) and (min-width: 768px) {
    #parent-fieldname-title {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (max-width: 767px) {
    #parent-fieldname-title {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) {
    #parent-fieldname-title {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    #parent-fieldname-title {
        padding-left: 120px;
        padding-right: 120px;
    }
}

#parent-fieldname-description {
    padding-left: 20px;
    padding-right: 20px;
}

@media (max-width: 979px) and (min-width: 768px) {
    #parent-fieldname-description {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (max-width: 767px) {
    #parent-fieldname-description {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) {
    #parent-fieldname-description {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    #parent-fieldname-description {
        padding-left: 120px;
        padding-right: 120px;
    }
}



/* Override media queries */

@media (min-width: 568px) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: left;
    }
}

@media (max-width: 767px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }
}

@media (min-width: 992px) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: left;
    }
}

@media (min-width: 1200px) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: center;
    }
}


/* COLLECTION */

#content-core .tileColumns {
    padding-top: 50px;
}

#content-core .thumb-image img {
    width: 100%;
    display: block;
    margin: 0 auto;
}

#content-core .thumbnail {
    background-color: inherit;
    border: none;
    box-shadow: none;
    -webkit-box-shadow: none;
    margin-bottom: 45px;
    padding: 0px;
}

#content-core .caption {
    padding: 0px;
}

#content-core .thumbnail h3 {
    margin-top: 12px; /* margin from title to image */
    margin-bottom: 4px;
    text-transform: none;
    font-family: "BrandonText-Medium";
    font-color: #242424;
    font-size: 18px;
    line-height: 26px;
}

#content-core .thumbnail a {
    text-decoration: none;
    color: #666666;
    font-size: 18px;
    border-bottom: none;
}

#content-core .thumbnail p {
    font-size: 18px;
    font-family: "BrandonText-Regular";
    color: #999999;
    line-height: 26px;
}

@media (max-width: 979px) and (min-width: 768px) {
    #content-core .tileColumns {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (max-width: 767px) {
    #content-core .tileColumns {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) {
    #content-core .tileColumns {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    #content-core .tileColumns {
        padding-left: 120px;
        padding-right: 120px;
    }

    .row-fluid .span4 {
        width: 31.034482759%;
        margin-left: 3.4482758621%;
    }

}


/* FOOTER */

#footer-manager-button {
    text-align: center;
}

#portal-footer-wrapper {
    padding-left: 0px;
    padding-right: 0px;
    padding-top: 70px;
    padding-bottom: 70px;
    background-color: #f4f4f4;
}

#FooterPortlet .portletWrapper:first-child {
    float:none;
    text-align: left;
    margin-top: 4px;
}

#FooterPortlet .portletWrapper {
    text-align: right;
}

#FooterPortlet .portletWrapper:first-child .portletStaticText {
    float:left;
}

#FooterPortlet .portletStaticText {
    float:right;
}

#FooterPortlet .portletWrapper p {
    font-family: "BrandonText-Regular";
    font-size: 16px;
    color: #999999;
    line-height: 15px;
}

#FooterPortlet h2 {
    font-family: "BrandonText-Medium";
    font-size: 16px;
    color: #666666;
    margin-top: 0px;
    line-height: 26px;
}

#FooterPortlet .span2:first-child {
    margin-left: 2.127659574468085%;
}

@media (max-width: 768px) {
    #FooterPortlet {
        padding-left: 25px;
        padding-right: 25px;
    }

    #FooterPortlet .portletWrapper:first-child {
        text-align: center;
    }
    #FooterPortlet .portletWrapper .portletStaticText {
        text-align: center;
        margin-bottom: 35px;
    }

    #FooterPortlet .span2:first-child {
        margin-left: 0px;
    }
}

@media (max-width: 979px) and (min-width: 768px) {
    #FooterPortlet .portletWrapper .span2 {
        margin-left: 2.7624309392265194%;
    }
}

@media (min-width: 992px) {
    #FooterPortlet {
        padding-left: 40px;
        padding-right: 40px;
    }

    #FooterPortlet .portletWrapper .span2 {
        margin-left: 2.127659574468085%;
    }
}

@media (min-width: 1200px) {
    #FooterPortlet {
        padding-left: 120px;
        padding-right: 120px;
    }

    #FooterPortlet .portletWrapper .span2 {
        margin-left: 2.564102564102564%;
    }
}

/* FRONT-PAGE COLLECTION */

#content-core .portletCollection .portletHeader {
    text-align: center;
}

#content-core .portletCollection .portletHeader h1 {
    font-family: 'BrandonText-Black';
    text-transform: uppercase;
    font-size: 24px;
    color: #242424;
    margin: 0px;
    line-height: 35px;
}

#content-core .portletCollection .portletHeader h2 {
    font-family: 'BrandonText-Regular';
    font-size: 18px;
    color: #999999;
    margin: 0px;
    line-height: 26px;
    margin-top: 5px;
}

#content-core .portletCollection .portletFooter {
    text-align: center;
    padding-bottom: 100px;
}

#content-core .portletCollection .portletHeader {
    padding-top: 100px;
    padding-bottom: 55px;
}

#content-core .portletCollection {
    background-color: #ffffff;
}

#content-core .portletCollection .thumbnail {
    background-color: inherit;
}

#content-core .portletCollection .portletFooter .btn {
    font-family: "BrandonText-Medium";
    color: #ffffff;
    font-size: 14px;
}

#content-core .portletCollection .portletFooter .btn-large {
    padding: 15px 30px;
}

@media (max-width: 979px) and (min-width: 768px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (max-width: 767px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 120px;
        padding-right: 120px;
    }
}

/* NEWSLETTER */

#content-core .portletMailChimp .portletHeader {
    text-align: center;
    padding-top: 100px;
    padding-bottom: 55px;
}

#content-core .portletMailChimp .portletHeader h1 {
    font-family: 'BrandonText-Black';
    text-transform: uppercase;
    font-size: 24px;
    color: #242424;
    margin: 0px;
    line-height: 35px;
}

#formfield-form-widgets-interest_groups {
    display: none;
}

#content-core .portletMailChimp .formControls {
    margin: 0px;
}

@media (max-width: 979px) and (min-width: 768px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (max-width: 767px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 120px;
        padding-right: 120px;
    }
}

/* PORTLETS General */

#portletPageTopRow > div:nth-child(odd) .portlet {
    background-color: #ffffff !important;
}

#portletPageTopRow > div:nth-child(odd) .portletHeader {
    background-color: #ffffff !important;
}

#portletPageTopRow > div:nth-child(even) .portlet {
    background-color: #f4f4f4 !important;
}

#portletPageTopRow > div:nth-child(even) .portletHeader {
    background-color: #f4f4f4 !important;
}


