Arnolfini.colorMapping = [
     {'tag': 'Exhibition', 'class': 'red'},
     {'tag': 'Family', 'class': 'green'},
     {'tag': 'Music', 'class': 'orange'},
     {'tag': 'Live', 'class': 'orange'},
     {'tag': 'Performance', 'class': 'purple'},
];

